## [1.1.1](https://github.com/ocni-dtu/lcax/compare/v1.1.0...v1.1.1) (2023-08-17)


### Bug Fixes

* added test cases and fixed issues with Python packaging ([39680eb](https://github.com/ocni-dtu/lcax/commit/39680eb98d07fa5f218d0bbbea09648d7314645b))

## [1.1.0](https://github.com/ocni-dtu/lcax/compare/v1.0.0...v1.1.0) (2023-08-16)


### Features

* updated result object ([feafef6](https://github.com/ocni-dtu/lcax/commit/feafef6e7870b02befddf9dc8aef9f062020bb8b))
* updated result object ([8e096c0](https://github.com/ocni-dtu/lcax/commit/8e096c07af19dd0bf53520481b86a5773400f7b3))
* updated transport object ([98da16b](https://github.com/ocni-dtu/lcax/commit/98da16b31f76f35cfe7b43579d29cd4e52395511))

## 1.0.0 (2023-08-16)


### Bug Fixes

* updated epdx package ([d474eac](https://github.com/ocni-dtu/lcax/commit/d474eac39d4544c5fde2f1383ddcf86d0845d894))
